-----------------------------------------------------------------------------------------------
-- Client Lua Script for ExitWindow
-- Copyright (c) NCsoft. All rights reserved
-----------------------------------------------------------------------------------------------

require "Window"
require "GameLib"

local ExitWindow = {}

function ExitWindow:new(o)
    o = o or {}
    setmetatable(o, self)
    self.__index = self

    o.kstrTitle = Apollo.GetString("Overview_Title")

    return o
end

function ExitWindow:Init()
    Apollo.RegisterAddon(self, false, self.kstrTitle)
end

function ExitWindow:OnLoad()
    self.xmlDoc = XmlDoc.CreateFromFile("ExitWindow.xml")
    self.xmlDoc:RegisterCallback("OnDocumentReady", self)
end

function ExitWindow:OnDocumentReady()
    if self.xmlDoc == nil then
        return
    end

    --Other Addons
    Apollo.RegisterEventHandler("ExitWindow_RequestParent",    "OnExitWindowRequestParent", self)

    --Exit
    Apollo.RegisterSlashCommand("camp",                            "OnCampSlashCommand", self)
    Apollo.RegisterEventHandler("PlayerCampStart",                "OnPlayerCampStart", self)
    Apollo.RegisterEventHandler("PlayerCampCancel",                "OnPlayerCampCancel", self)

    local tExitInfo = GameLib.GetGameExitInfo()

    if tExitInfo.ePendingEvent == GameLib.CodeEnumExitEvent.Quit or tExitInfo.ePendingEvent == GameLib.CodeEnumExitEvent.Camp then
        self:OnPlayerCampStart()
    end
end

function ExitWindow:OnCampSlashCommand()
    Camp()
    self:OnPlayerCampStart()--Trying to camp when there is a pending camp will NOT fire the event PlayerCampStart.
end

function ExitWindow:OnExitWindowRequestParent()
    if not self.wndTeaser then
        return
    end

    Event_FireGenericEvent("ExitWindow_RequestContent", self.wndTeaser)
end

function ExitWindow:OnPlayerCampStart()
    if self.wndMain then
        self.wndMain:Destroy()
        self.wndMain = nil
    end

    local tExitInfo = GameLib.GetGameExitInfo()
    if not tExitInfo then
        return
    end

    if tExitInfo.ePendingEvent == GameLib.CodeEnumExitEvent.Camp and tExitInfo.fTimeRemaining <= 0 then
        return
    end

    self.wndMain = Apollo.LoadForm(self.xmlDoc, "ExitWindowOverview", nil, self)
    self.timerGameExit = ApolloTimer.Create(0.5, true, "OnTimer", self)

    local strMessage = ""

    if tExitInfo.ePendingEvent == GameLib.CodeEnumExitEvent.Quit then
        strMessage = Apollo.GetString("GameExit_TimeTillQuit")
    elseif tExitInfo.ePendingEvent == GameLib.CodeEnumExitEvent.Camp then
        strMessage = Apollo.GetString("GameExit_TimeTillCamp")
    end

    self.wndMain:FindChild("Message"):SetText(strMessage)

    self.wndMain:Invoke()
end

function ExitWindow:OnTimer(nTime)
    local tExitInfo = GameLib.GetGameExitInfo()

    if not tExitInfo or not self.wndMain then--make sure the timer is not running when no main
        return
    end

    local bCountDown = tExitInfo.fTimeRemaining > 0
    local wndExitContent = self.wndMain:FindChild("ExitContent")

    wndExitContent:Show(bCountDown)

    self.wndMain:FindChild("btnExitGame"):Enable(not bCountDown or tExitInfo.ePendingEvent == GameLib.CodeEnumExitEvent.Quit)

    if bCountDown then
        local nSeconds = math.floor(tExitInfo.fTimeRemaining)
        local strOutput = Apollo.GetString("GameExit_NumTimer")

        if nSeconds < 10 then
            strOutput = Apollo.GetString("GameExit_ShortTimer")
        end

        wndExitContent:FindChild("Timer"):SetText(String_GetWeaselString(strOutput, nSeconds))
    end
end

function ExitWindow:OnExitGameBtn()
    ConfirmCamp()
    self:CleanUp()
end

function ExitWindow:OnPlayerCampCancel()
    self:OnCancel()
end

function ExitWindow:OnCancel()
    CancelExit()
    self:CleanUp()
end

function ExitWindow:CleanUp()
    if self.timerGameExit then
        self.timerGameExit:Stop()
        self.timerGameExit = nil
    end

    if self.wndMain then
        self.wndMain:Destroy()
        self.wndMain = nil
        self.wndExitSurvey = nil
        self.wndTeaser = nil
    end
end

-----------------------------------------------------------------------------------------------
-- ExitWindow Instance
-----------------------------------------------------------------------------------------------
local ExitWindowInst = ExitWindow:new()
ExitWindowInst:Init()
