-----------------------------------------------------------------------------------------------
-- Client Lua Script for WelcomeWindow
-- Copyright (c) NCsoft. All rights reserved
-----------------------------------------------------------------------------------------------

require "Window"
require "AccountItemLib"
require "MatchMakingLib"
require "MatchMakingEntry"
require "GameLib"

local WelcomeWindow = {}

function WelcomeWindow:new(o)
    o = o or {}
    setmetatable(o, self)
    self.__index = self

    o.kstrTitle = Apollo.GetString("WelcomeWindow_Title")

    return o
end

function WelcomeWindow:Init()
    Apollo.RegisterAddon(self, false, "LUI WelcomeWindow")
end

function WelcomeWindow:OnLoad()
    self.xmlDoc = XmlDoc.CreateFromFile("WelcomeWindow.xml")
    self.xmlDoc:RegisterCallback("OnDocumentReady", self)
end

function WelcomeWindow:OnDocumentReady()
    if self.xmlDoc == nil then
        return
    end

    --WindowManagement
    Apollo.RegisterEventHandler("WindowManagementReady",     "OnWindowManagementReady", self)
    self:OnWindowManagementReady()

    --InterfaceMenuList
    Apollo.RegisterEventHandler("InterfaceMenuListHasLoaded",         "OnInterfaceMenuListHasLoaded", self)
    Apollo.RegisterEventHandler("WelcomeWindow_RequestParent",        "OnRequestWelcomeWindowParent", self)

    --Open Welcome Window from code
    Apollo.RegisterEventHandler("ToggleWelcomeWindow",                "OnToggle", self)
    Apollo.RegisterEventHandler("LiveEvent_ToggleWindow",            "OnLiveEvent_ToggleWindow", self)

    --Open Welcome Window from Other Addons
    Apollo.RegisterEventHandler("WelcomeWindow_Open",     "OnOpen", self)
    Apollo.RegisterEventHandler("WelcomeWindow_Toggle", "OnToggle", self)

    self.wndMain = Apollo.LoadForm(self.xmlDoc, "WelcomeContainer", nil, self)
    self.wndContentContainer = self.wndMain:FindChild("ContentContainer")
    self.wndMain:FindChild("NavContainer"):FindChild("DailyRewards"):SetCheck(true)

    self:OnInterfaceMenuListHasLoaded()
    self:OnRequestWelcomeWindowParent()
end

function WelcomeWindow:OnWindowManagementReady()
    Event_FireGenericEvent("WindowManagementRegister", {strName = self.kstrTitle, nSaveVersion = 1})
    Event_FireGenericEvent("WindowManagementAdd", {wnd = self.wndMain, strName = self.kstrTitle})
end

function WelcomeWindow:OnInterfaceMenuListHasLoaded()
    Event_FireGenericEvent("InterfaceMenuList_NewAddOn", self.kstrTitle, { "WelcomeWindow_Toggle", "", "IconSprites:Icon_Windows32_UI_CRB_InterfaceMenu_WelcomeWindow2"})
end

function WelcomeWindow:OnRequestWelcomeWindowParent()
    Event_FireGenericEvent("WelcomeWindow_Loaded", self.wndContentContainer)
end

function WelcomeWindow:OnTabBtn(wndHandler, wndControl)
    for _,child in pairs(self.wndMain:FindChild("ContentContainer"):GetChildren()) do
        if child:GetName() == wndControl:GetName() then
            child:Show(true)
        else
            child:Show(false)
        end
    end
end

function WelcomeWindow:OnLiveEvent_ToggleWindow()
    if not self.wndMain or not self.wndMain:IsValid() then
        return
    end

    for _,child in pairs(self.wndMain:FindChild("ContentContainer"):GetChildren()) do
        if child:GetName() == "LiveEvents" then
            child:Show(true)
        else
            child:Show(false)
        end
    end

    for _,child in pairs(self.wndMain:FindChild("NavContainer"):GetChildren()) do
        if child:GetName() == "LiveEvents" then
            child:SetCheck(true)
        else
            child:SetCheck(false)
        end
    end

    self:OnOpen()
end

function WelcomeWindow:OnToggle()
    if self.wndMain and self.wndMain:IsShown() then
        self:OnCancel()
        return
    end

    self:OnOpen()
end

function WelcomeWindow:OnOpen()
    if self.wndMain then
        self.wndMain:Invoke()
    end
end

function WelcomeWindow:OnCancel()
    self.wndMain:Close()
end

-----------------------------------------------------------------------------------------------
-- WelcomeWindow Instance
-----------------------------------------------------------------------------------------------
local WelcomeWindowInst = WelcomeWindow:new()
WelcomeWindowInst:Init()
